@@ -17,11 +17,7 @@ class PipelineInstance(PipelineBase):
             Defines what dataset + version this pipeline instance should result in. e.g. Running the pipeline instance
             should create a new edition in this dataset + version combination.
         pipelineArn: What Pipeline should be used.
-        schemaId: Id for a schema. Used to validate the input or output.
-            TODO: For now it's up to the pipeline to include a validation step. So this might not be in use even if supplied.
-        transformation: object Transformation for the given Pipeline. Should include config for each step in
-            the state-machine if needed. Should be validated against Pipeline.transformation_schema
-        useLatestEdition: bool Whether or not to create a new edition or use the latest edition when running the pipeline.
+        pipelineProcessorId: ID of the pipeline processor to use.
     """
 
     __resource_name__ = "pipeline-instances"
@@ -35,35 +31,58 @@ class PipelineInstance(PipelineBase):
         sdk: SDK,
         id: str,
         datasetUri: str,
-        pipelineArn: str,
-        schemaId: str,
-        taskConfig: object,
-        useLatestEdition: bool,
-        transformation: object = None,
+        taskConfig: object = None,
+        # TODO: Remove this once all users have been updated to use
+        # `pipelineProcessorId` instead.
+        pipelineArn: str = None,
+        # TODO: Make this required once `pipelineArn` has been phased out.
+        pipelineProcessorId: str = None,
     ):
         self.sdk = sdk
         self._id = id
         self.datasetUri = datasetUri
         self.pipelineArn = pipelineArn
-        self.schemaId = schemaId
-        self.transformation = transformation
+        self.pipelineProcessorId = pipelineProcessorId
         self.taskConfig = taskConfig
-        self.useLatestEdition = useLatestEdition
 
     @property
     def __dict__(self):
         dictionary = {
             "id": self.id,
             "datasetUri": self.datasetUri,
-            "pipelineArn": self.pipelineArn,
-            "schemaId": self.schemaId,
             "taskConfig": self.taskConfig,
-            "useLatestEdition": self.useLatestEdition,
         }
-        if self.transformation is not None:
-            dictionary["transformation"] = self.transformation
+        if self.taskConfig is not None:
+            dictionary["taskConfig"] = self.taskConfig
+        if self.pipelineArn is not None:
+            dictionary["pipelineArn"] = self.pipelineArn
+        if self.pipelineProcessorId is not None:
+            dictionary["pipelineProcessorId"] = self.pipelineProcessorId
         return dictionary
 
+    @classmethod
+    def from_dict(cls, sdk: SDK, instance_dict: dict):
+        """Create and return a pipeline instance from a dictionary.
+
+        Overrides the method from `PipelineBase` to be able to pick and choose
+        from `instance_dict`, instead of requiring an exact match with this
+        class' `___init___` parameters.
+        """
+        return cls(
+            sdk,
+            **{
+                key: instance_dict[key]
+                for key in [
+                    "id",
+                    "datasetUri",
+                    "taskConfig",
+                    "pipelineArn",
+                    "pipelineProcessorId",
+                ]
+                if key in instance_dict
+            },
+        )
+
     def __repr__(self):
         return json.dumps(self.__dict__)
 
